@@ -4,8 +4,14 @@
 #---------------------------------------------------------------------------
 import jsm
 
-def test_parser():
+def test_search():
     q = jsm.Quotes()
-    result = q.search('NTT')
+    result = q.search('グリー')
+    assert result[0].ccode == '3632'
+    result = q.search('3632')
+    assert result[0].ccode == '3632'
+    result = q.search('NTTドコモ')
     assert result[0].ccode == '9437'
+    result = q.search('0000')
+    assert len(result) == 0
     
\ No newline at end of file
